## 1.0.0

Translation and Benchmarking tools, integration of NodeJS and esbuild for bundling, full rewrite of the JavaScript API to TypeScript.
A huge amount of bug fixes, optimizations and UX improvements.

**Editor**
- CLI
    - Fix --import command not instantiating the scene
    - Tokens were added as a more secure method of passing credentials to the editor for packaging on CI
    - Added benchmarking framework
- Linux
    - Fixed file watching
    - Fixed modifier key states
- Packaging: Removed unused VR and AR button SVGs
- SceneLoading: Optimized mesh processing
- Windows: Fixed random error messages produce from file watch
- Added Benchmarking view
- Added Localization view to aid translation of WebXR experiences
- Added WL_EDITOR JavaScript macro, which is set to `true` for when the editor bundles components
- Added alpha value slider to color pickers
- Added choice for ETC1S (smaller, default) and UASTC (higher quality) for image compression
- Added defaults for Sky Material colorStop properties
- Added devices drop-down to launch page directly on connected Android devices instead of local device (port forwarding automatically set up)
- Animation component with empty animations are now inactive at runtime
- Automatically detect components from scripts and npm packages
- Fixed a rare bug where a component added in the editor could return `undefined` when retrieved at runtime
- Fixed random darkening of the entire UI when making various changes to the project
- Fixed rotation Gizmo behavior on objects with non-uniform scaled ancestors
- Fixed crashes when switching projects
- Made all color property alpha values default to `1.0`
- Negative text component spacing values can now be set
- Removed legacy JavaScript bundler in favor of default "esbuild" bundler
- Text materials now have thumbnails
- Fonts now have thumbnails
- Views
    - AssetBrowser: Deleted files are now moved into system trash folder instead of deleting permanently
    - Console: Error, Warning, Info checkbox states are now persisted per project
    - Console: Fixed horizontal scroll
    - ProjectSettings: Fixed huge lag when changing editor server port
    - Properties: Fixed pasting of Euler rotations
    - ResourcesView: Added horizontal scroll to ensure entirety of the tables can be read even on smaller screens

**Engine**
- Rendering
    - Fixed texture seam on Sky shader
    - Updated to latest Slug Library
- Fixed shadowing bug due to internal shadow count was not updated
- Improved GPU profiling queries
- Negative animation speed now plays the animation backwards
- Shaders are now compiled asynchronously for even faster loading times
- Support UASTC compression
- Switched animation engine for upcoming features
- Systematically fix various rare crashes due to out of bounds array access
- Phong
    - Ambient term is now retrieved by multiplying ambient color with the diffuse term
    - Diffuse color is now multiplied with the diffuse texture
    - Vertex color is now multiplied with diffuse texture and color
- Flat
    - Vertex color is now multiplied with color and texture

**Runtime**
- PWA: Fixed various files not cached by service worker for offline use
- Fixed a potential crash in Profiler
- Fixed input type "Head"
- Fully consumed .bin file data is now discarded after load, improving memory use
- It is now possible to use multiple engine instances on a single webpage
- Lowered maximum available WebAssembly memory to 512 MB for better debugging experience and older iOS hardware compatibility
- The WebAssembly is now properly modularized to allow use with any other WebAssembly module

**JavaScript API**
- TypeScript
    - Added `@property.<type>` decorator to define configurable properties directly in the class body
    - Fully rewrote the API in TypeScript
- Added `PhysXComponent.group`, `PhysXComponent.block` and many more missing properties
- Added `XR.currentReferenceSpace`, `XR.currentReferenceSpaceType` and `XR.referenceSpaceForType`
- Added `XR` and `WonderlandEngine.xr` for access to WebXR related state
- Added a huge amount of new automated tests
- Added a new `Color` property type
- Added equals() methods for Mesh, Material, Texture, Animation and Skin
- Added setter for LightComponent.color
- All of the API's global state has been removed
- Custom components are now classes: `export class CustomComponent extends Component`
- Fixed `AnimationComponent.state` returning incorrect enum values
- Fixed `Object3D.lookAt()` and clarified its behavior in the documentation
- Fixed cloning of components with `Object3D.addComponent(type, otherComponent)`
- Made default parameters apply consistent with the editor
- Removed `onXRSupported` callback, as `WonderlandEngine.arSupported` and `WonderlandEngine.vrSupported` are now available from the start of the application
- Renamed `Material.shader` to `Material.pipeline`
- Replaced callbacks arrays (`onSceneLoaded`, `onXRSessionStart`, ...) with a new `Emitter` class
- `AnimationComponent.animation` now properly returns `null` when unset
- `Component.onDestroy` is now called when a new scene is loaded
- `Object` is now `Object3D` to avoid shadowing built-in JavaScript type

**Components**
- Converted all components to classes
- Converted some components to TypeScript
- components: Add trail component
- cursor-target: Deprecated `add*Function` in favor of `onClick`, `onHover`, `onUnhover`, `onMove` event emitters

**Known Issues**
- Animation retargeting is broken
- Input via WebXR Emulator extensions doesn't work
- Missing custom components can cause a packaging loop on Windows
